@@ -2,15 +2,11 @@ import logging
 import re
 
 MENTION_REGEX = re.compile("^<@(|[WU].+?)>(.*)")
-LINK_REGEX = re.compile("<(http.*?)(\|.*?)?>", re.DOTALL)
+LINK_REGEX = re.compile(r"<(http.*?)(\|.*?)?>", re.DOTALL)
 
 logger = logging.getLogger(__name__)
 
 
-class CommandError(Exception):
-    pass
-
-
 def parse_direct_mention(message_text):
     """
     Finds a direct mention (a mention that is at the beginning) in message text
